"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AlgorithmBase = void 0;
class AlgorithmBase {
    constructor(_bestChanged = undefined) {
        this._bestChanged = _bestChanged;
        this._chromosomes = [];
        this._fitness = 0;
    }
    get generationNumber() {
        // eslint-disable-next-line no-magic-numbers
        return this.islands.reduce((acc, island) => acc + island.generationNumber, 0);
    }
    get offspringNumber() {
        // eslint-disable-next-line no-magic-numbers
        return this.islands.reduce((acc, island) => acc + island.offspringNumber, 0);
    }
    get initialized() {
        return this.islands.every(island => island.initialized);
    }
    get chromosomes() {
        return this._chromosomes;
    }
    get migration() {
        return undefined;
    }
    get best() {
        return this._chromosomes[0];
    }
    get progress() {
        return this.termination.progress;
    }
    get hasReached() {
        return this.termination.hasReached(this);
    }
    resetChromosomes() {
        this._chromosomes.length = 0;
        this.islands.forEach(island => {
            island.population.chromosomes.forEach(chromosome => {
                this._chromosomes.push(chromosome);
            });
        });
    }
    updateChromosomes() {
        this._chromosomes.sort((c1, c2) => c2.fitness - c1.fitness);
        if (this._chromosomes.length) {
            const bestFitness = this._chromosomes[0].fitness;
            // eslint-disable-next-line no-magic-numbers
            if (bestFitness >= 0 && bestFitness !== this._fitness) {
                this._fitness = bestFitness;
                if (this._bestChanged) {
                    this._bestChanged();
                }
            }
        }
    }
    reset() {
        var _a;
        this.islands.forEach(island => island.reset());
        this.resetChromosomes();
        (_a = this.migration) === null || _a === void 0 ? void 0 : _a.init();
        this.termination.init();
        this.updateChromosomes();
        this.performReset();
    }
    performReset() {
        // override if required
    }
    step() {
        var _a;
        if (this.hasReached) {
            return;
        }
        this.islands.forEach(island => island.step());
        (_a = this.migration) === null || _a === void 0 ? void 0 : _a.migrate(this);
        this.updateChromosomes();
        this.performStep();
    }
    performStep() {
        // override if required
    }
}
exports.AlgorithmBase = AlgorithmBase;
//# sourceMappingURL=AlgorithmBase.js.map