"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChromosomeBase = void 0;
class ChromosomeBase {
    constructor(_length, skipLengthCheck = false) {
        // eslint-disable-next-line no-magic-numbers
        if (!skipLengthCheck && _length < 1) {
            throw new Error('Too short.');
        }
        this.acids = new Array(_length);
    }
    createFromAcids(acids) {
        this.acids = [...acids];
    }
    get length() {
        return this.acids.length;
    }
    getAcid(index) {
        return this.acids[index];
    }
    setAcid(index, acid) {
        this.acids[index] = acid;
    }
    deleteAcid(index) {
        // eslint-disable-next-line no-magic-numbers
        this.acids.splice(index, 1);
    }
    insertAcid(index, acid) {
        // eslint-disable-next-line no-magic-numbers
        this.acids.splice(index, 0, acid);
    }
    generateAcids() {
        [...Array(this.length).keys()].forEach(index => this.setAcid(index, this.generateAcid(index)));
    }
    clone() {
        const clone = this.createNew();
        clone.copyFrom(this);
        return clone;
    }
    copyFrom(from) {
        if (from.length !== this.length) {
            this.acids = new Array(from.length);
        }
        // eslint-disable-next-line no-magic-numbers
        for (let index = from.length; --index >= 0;) {
            this.acids[index] = from.getAcid(index);
        }
        this.performCopyFrom(from);
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    performCopyFrom(_from) {
        // override if required
    }
    mutation(index) {
        this.acids[index] = this.generateAcid(index);
    }
}
exports.ChromosomeBase = ChromosomeBase;
//# sourceMappingURL=ChromosomeBase.js.map