"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IslandBase = void 0;
class IslandBase {
    constructor() {
        // eslint-disable-next-line no-magic-numbers
        this._generationNumber = 0;
        // eslint-disable-next-line no-magic-numbers
        this._offspringNumber = 0;
        this._initialized = false;
    }
    get generationNumber() {
        return this._generationNumber;
    }
    get offspringNumber() {
        return this._offspringNumber;
    }
    get initialized() {
        return this._initialized;
    }
    reset() {
        this._initialized = false;
        this.population.init();
        this.population.chromosomes.forEach((chromosome) => {
            this.fitness.evaluate(chromosome);
        });
        this._generationNumber = 0;
        this._offspringNumber = 0;
        this.performReset();
        this._initialized = true;
    }
    performReset() {
        // override if required
    }
    performMutate(chromosomes) {
        chromosomes.forEach((chromosome) => {
            this.mutation.mutate(chromosome);
        });
    }
    performEvaluate(chromosomes) {
        chromosomes.forEach((chromosome) => {
            this.fitness.evaluate(chromosome);
        });
    }
    step() {
        if (!this._initialized) {
            this.reset();
        }
        const { parents, population } = this.selection.select(this.population.chromosomes);
        const offspring = this.crossover.cross(parents);
        const offspringCount = offspring.length;
        this.performMutate(offspring);
        const evaluateTargets = [...offspring];
        parents.forEach(parent => {
            evaluateTargets.push(parent);
        });
        this.performEvaluate(evaluateTargets);
        const newGeneration = this.reinsertion.select(population, offspring, parents);
        this.population.update(newGeneration);
        this._generationNumber++;
        this._offspringNumber += offspringCount;
        this.performStep();
    }
    performStep() {
        // override if required
    }
}
exports.IslandBase = IslandBase;
//# sourceMappingURL=IslandBase.js.map