"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PopulationBase = void 0;
class PopulationBase {
    constructor(_size, _adamChromosome) {
        this._size = _size;
        this._adamChromosome = _adamChromosome;
        this._chromosomes = [];
        this._pool = [];
        [...Array(_size)].forEach(() => {
            this._pool.push(_adamChromosome.clone());
        });
    }
    get chromosomes() {
        return this._chromosomes;
    }
    get size() {
        return this._size;
    }
    init() {
        this._chromosomes = new Array();
        [...Array(this.size)].forEach(() => this._chromosomes.push(this._adamChromosome.createNew()));
        this.performInit();
    }
    performInit() {
        // override if required
    }
    update(chromosomes) {
        if (this.size !== chromosomes.length) {
            throw new Error('Population size does not match the setting.');
        }
        // eslint-disable-next-line no-magic-numbers
        for (let index = chromosomes.length; --index >= 0;) {
            this._pool[index].copyFrom(chromosomes[index]);
        }
        // eslint-disable-next-line no-magic-numbers
        for (let index = this._pool.length; --index >= 0;) {
            this._chromosomes[index].copyFrom(this._pool[index]);
        }
    }
}
exports.PopulationBase = PopulationBase;
//# sourceMappingURL=PopulationBase.js.map